@@ -6,7 +6,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 =head1 NAME
 
@@ -95,7 +95,7 @@ use WeakRef;
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 =head1 NAME
 
@@ -167,12 +167,11 @@ sub _newroot {
 =cut
 sub fetch {
     my( $self, $id ) = @_;
-
     return undef unless $id;
     #
     # Return the object if we have a reference to its dirty state.
     #
-    my $ref = $self->{_DIRTY}->{$id} || $self->{_WEAK_REFS}->{$id};
+    my $ref = $self->{_DIRTY}{$id} || $self->{_WEAK_REFS}{$id};
     if( defined $ref ) {
         return $ref;
     }
@@ -197,10 +196,12 @@ sub fetch {
         else {
             my $obj;
             eval {
-                $class =~ /^Yote::/ || eval("require $class");
+                my $path = $class;
+                $path =~ s!::!/!g;
+                $INC{"${path}.pm"} || eval("require $class");
                 $obj = $class->_instantiate( $id, $self );
             };
-            return undef if $@;
+            die $@ if $@;
             $obj->{DATA} = $data;
             $obj->{ID} = $id;
             $obj->_load();
@@ -257,6 +258,7 @@ sub _new { #Yote::ObjStore
     my $self = bless {
         _DIRTY     => {},
         _WEAK_REFS => {},
+        args       => $args,
     }, $pkg;
     $self->{_DATASTORE} = Yote::YoteDB->open( $self, $args );
     $self;
@@ -508,7 +510,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 #
 # The string version of the yote object is simply its id. This allows
@@ -717,7 +719,7 @@ use Tie::Array;
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 sub TIEARRAY {
     my( $class, $obj_store, $id, @list ) = @_;
@@ -792,8 +794,6 @@ sub SPLICE {
 }
 sub EXTEND {}
 
-sub DESTROY {}
-
 # ---------------------------------------------------------------------------------------------------------------------
 
 package Yote::Hash;
@@ -812,7 +812,7 @@ use Tie::Hash;
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 sub TIEHASH {
     my( $class, $obj_store, $id, %hash ) = @_;
@@ -885,7 +885,7 @@ use constant {
 
 use vars qw($VERSION);
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 #
 # This the main index and stores in which table and position
@@ -896,7 +896,7 @@ sub open {
   my $class = ref( $pkg ) || $pkg;
 
   my $self = bless {
-      args          => $args,
+      args       => $args,
       OBJ_STORE  => $obj_store,
       DATA_STORE => DB::DataStore->open( $args->{ store } ),
   }, $class;
@@ -1069,6 +1069,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.1  (October 10, 2015))
+       Version 1.2  (November 2, 2015))
 
 =cut
